@@ -36,14 +36,11 @@
 #include <QFrame>
 #include <QScrollArea>
 
-namespace Akonadi
-{
+namespace Akonadi {
 class IncidenceChanger;
 }
 
-namespace EventViews
-{
-
+namespace EventViews {
 class Agenda;
 class AgendaItem;
 class AgendaView;
@@ -54,7 +51,7 @@ class MarcusBains : public QFrame
 public:
     explicit MarcusBains(EventView *eventView, Agenda *agenda = nullptr);
     void updateLocationRecalc(bool recalculate = false);
-    virtual ~MarcusBains();
+    ~MarcusBains() override;
 
 public Q_SLOTS:
     void updateLocation();
@@ -68,12 +65,12 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
 {
     Q_OBJECT
 public:
-    Agenda(AgendaView *agendaView, QScrollArea *scrollArea,
-           int columns, int rows, int rowSize, bool isInteractive);
+    Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, int rows, int rowSize,
+           bool isInteractive);
 
     Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, bool isInteractive);
 
-    virtual ~Agenda();
+    ~Agenda() override;
 
     KCalCore::Incidence::Ptr selectedIncidence() const;
     QDate selectedIncidenceDate() const;
@@ -123,14 +120,16 @@ public:
 
     void setStartTime(const QTime &startHour);
 
-    AgendaItem::QPtr insertItem(const KCalCore::Incidence::Ptr &incidence, const KDateTime &recurrenceId, int X, int YTop,
-                                int YBottom, int itemPos, int itemCount, bool isSelected);
+    AgendaItem::QPtr insertItem(const KCalCore::Incidence::Ptr &incidence,
+                                const QDateTime &recurrenceId, int X, int YTop, int YBottom,
+                                int itemPos, int itemCount, bool isSelected);
 
-    AgendaItem::QPtr insertAllDayItem(const KCalCore::Incidence::Ptr &event, const KDateTime &recurrenceId, int XBegin,
-                                      int XEnd, bool isSelected);
+    AgendaItem::QPtr insertAllDayItem(const KCalCore::Incidence::Ptr &event,
+                                      const QDateTime &recurrenceId, int XBegin, int XEnd,
+                                      bool isSelected);
 
-    void insertMultiItem(const KCalCore::Incidence::Ptr &event, const KDateTime &recurrenceId, int XBegin, int XEnd,
-                         int YTop, int YBottom, bool isSelected);
+    void insertMultiItem(const KCalCore::Incidence::Ptr &event, const QDateTime &recurrenceId,
+                         int XBegin, int XEnd, int YTop, int YBottom, bool isSelected);
 
     /**
       Removes an event and all its multi-items from the agenda. This function
@@ -237,7 +236,7 @@ private:
     };
 
     AgendaItem::QPtr createAgendaItem(const KCalCore::Incidence::Ptr &incidence, int itemPos,
-                                      int itemCount, const KDateTime &recurrentId, bool isSelected);
+                                      int itemCount, const QDateTime &recurrentId, bool isSelected);
 
 protected:
     /**
@@ -271,7 +270,8 @@ protected:
         @param pos The current mouse position
         @param item The affected item
     */
-    MouseActionType isInResizeArea(bool horizontal, const QPoint &pos, const AgendaItem::QPtr &item);
+    MouseActionType isInResizeArea(bool horizontal, const QPoint &pos,
+                                   const AgendaItem::QPtr &item);
     /** Return whether the cell specified by the grid point belongs to the current select
     */
     bool ptInSelection(const QPoint &gpos) const;
@@ -350,11 +350,8 @@ public:
     Agenda *agenda() const;
 
 private:
-    Agenda *mAgenda;
-
+    Agenda *mAgenda = nullptr;
 };
-
 }
 
 #endif
-
