@@ -27,13 +27,17 @@
 #include "timelabelszone.h"
 #include "timescaleconfigdialog.h"
 
+#include <KCalUtils/Stringify>
+
 #include <KLocalizedString>
 
 #include <QFrame>
+#include <QHelpEvent>
 #include <QIcon>
 #include <QMenu>
 #include <QPainter>
 #include <QPointer>
+#include <QToolTip>
 
 using namespace EventViews;
 
@@ -56,10 +60,6 @@ TimeLabels::TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent,
     colorMousePos();
     mAgenda = nullptr;
 
-    if (mTimezone.isValid()) {
-        setToolTip(i18n("Timezone:") + i18n(mTimezone.id().constData()));
-    }
-
     setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
 
     updateConfig();
@@ -171,6 +171,59 @@ void TimeLabels::setAgenda(Agenda *agenda)
     }
 }
 
+int TimeLabels::yposToCell(const int ypos) const
+{
+   const auto firstDay =
+       QDateTime(mAgenda->dateList().first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
+    const int beginning = // the hour we start drawing with
+        !mTimezone.isValid() ?
+        0 :
+        (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
+    return static_cast<int>(ypos / mCellHeight) + beginning;
+}
+
+int TimeLabels::cellToHour(const int cell) const
+{
+    int tCell = cell % 24;
+    // handle different timezones
+    if (tCell < 0) {
+        tCell += 24;
+    }
+    // handle 24h and am/pm time formats
+    if (use12Clock()) {
+        if (tCell == 0) {
+            tCell = 12;
+        }
+        if (tCell < 0) {
+            tCell += 24;
+        }
+        if (tCell > 12) {
+            tCell %= 12;
+            if (tCell == 0) {
+                tCell = 12;
+            }
+        }
+    }
+    return tCell;
+}
+
+QString TimeLabels::cellToSuffix(const int cell) const
+{
+    //TODO: rewrite this using QTime's time formats. "am/pm" doesn't make sense
+    // in some locale's
+    QString suffix;
+    if (use12Clock()) {
+        if ((cell / 12) % 2 != 0) {
+            suffix = QStringLiteral("pm");
+        } else {
+            suffix = QStringLiteral("am");
+        }
+    } else {
+        suffix = QStringLiteral("00");
+    }
+    return suffix;
+}
+
 /** This is called in response to repaint() */
 void TimeLabels::paintEvent(QPaintEvent *)
 {
@@ -184,13 +237,12 @@ void TimeLabels::paintEvent(QPaintEvent *)
     // We won't paint parts that aren't visible
     const int cy = -y();// y() returns a negative value.
 
-    const auto firstDay
-        = QDateTime(mAgenda->dateList().first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
-    const int beginning
-        = !mTimezone.isValid()
-          ? 0
-          : (mTimezone.offsetFromUtc(firstDay)
-             -mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / (60 * 60);
+    const auto firstDay =
+        QDateTime(mAgenda->dateList().first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
+    const int beginning =
+        !mTimezone.isValid() ?
+        0 :
+        (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
 
     // bug:  the parameters cx and cw are the areas that need to be
     //       redrawn, not the area of the widget.  unfortunately, this
@@ -201,7 +253,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
     const int cw = width();
     // end of workaround
 
-    int cell = static_cast<int>(cy / mCellHeight) + beginning;    // the hour we start drawing with
+    int cell = yposToCell(cy);
     double y = (cell - beginning) * mCellHeight;
     QFontMetrics fm = fontMetrics();
     QString hour;
@@ -216,9 +268,6 @@ void TimeLabels::paintEvent(QPaintEvent *)
         suffix = QStringLiteral("00");
     } else {
         suffix = QStringLiteral("am");
-        if (cell > 11) {
-            suffix = QStringLiteral("pm");
-        }
     }
 
     // We adjust the size of the hour font to keep it reasonable
@@ -258,23 +307,9 @@ void TimeLabels::paintEvent(QPaintEvent *)
         // hour, full line
         p.drawLine(cx, int(y), cw + 2, int(y));
 
-        hour.setNum(cell % 24);
-        // handle different timezones
-        if (cell < 0) {
-            hour.setNum(cell + 24);
-        }
-        // handle 24h and am/pm time formats
-        if (use12Clock()) {
-            if (cell == 12) {
-                suffix = QStringLiteral("pm");
-            }
-            if (cell == 0) {
-                hour.setNum(12);
-            }
-            if (cell > 12) {
-                hour.setNum(cell - 12);
-            }
-        }
+        // set the hour and suffix from the cell
+        hour.setNum(cellToHour(cell));
+        suffix = cellToSuffix(cell);
 
         // draw the time label
         p.setPen(textColor);
@@ -302,22 +337,19 @@ void TimeLabels::contextMenuEvent(QContextMenuEvent *event)
     Q_UNUSED(event);
 
     QMenu popup(this);
-    QAction *editTimeZones
-        = popup.addAction(QIcon::fromTheme(QStringLiteral("document-properties")),
-                          i18n("&Add Timezones..."));
-    QAction *removeTimeZone
-        = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
-                          i18n("&Remove Timezone %1", i18n(mTimezone.id().constData())));
-    if (!mTimezone.isValid()
-        || !mTimeLabelsZone->preferences()->timeScaleTimezones().count()
-        || mTimezone == mTimeLabelsZone->preferences()->timeZone()) {
+    QAction *editTimeZones = popup.addAction(QIcon::fromTheme(QStringLiteral("document-properties")),
+                                             i18n("&Add Timezones..."));
+    QAction *removeTimeZone = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
+                                              i18n("&Remove Timezone %1", i18n(mTimezone.id().constData())));
+    if (!mTimezone.isValid() ||
+        !mTimeLabelsZone->preferences()->timeScaleTimezones().count() ||
+        mTimezone == mTimeLabelsZone->preferences()->timeZone()) {
         removeTimeZone->setEnabled(false);
     }
 
     QAction *activatedAction = popup.exec(QCursor::pos());
     if (activatedAction == editTimeZones) {
-        QPointer<TimeScaleConfigDialog> dialog
-            = new TimeScaleConfigDialog(mTimeLabelsZone->preferences(), this);
+        QPointer<TimeScaleConfigDialog> dialog = new TimeScaleConfigDialog(mTimeLabelsZone->preferences(), this);
         if (dialog->exec() == QDialog::Accepted) {
             mTimeLabelsZone->reset();
         }
@@ -345,34 +377,64 @@ QString TimeLabels::header() const
 
 QString TimeLabels::headerToolTip() const
 {
+    QDateTime now = QDateTime::currentDateTime();
     QString toolTip;
+
     toolTip += QLatin1String("<qt>");
-    toolTip += i18n("<b>%1</b>", i18n(mTimezone.id().constData()));
+    toolTip += i18nc("title for timezone info, the timezone id and utc offset",
+                     "<b>%1 (%2)</b>", i18n(mTimezone.id().constData()),
+                     KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
     toolTip += QLatin1String("<hr>");
-    //TODO: Once string freeze is lifted, add UTC offset here
+    toolTip += i18nc("heading for timezone display name",
+                     "<i>Name:</i> %1", mTimezone.displayName(now, QTimeZone::LongName));
+    toolTip += QLatin1String("<br/>");
+
     if (mTimezone.country() != QLocale::AnyCountry) {
-        toolTip += i18n("<i>Country:</i> %1", QLocale::countryToString(mTimezone.country()));
+        toolTip += i18nc("heading for timezone country",
+                         "<i>Country:</i> %1", QLocale::countryToString(mTimezone.country()));
         toolTip += QLatin1String("<br/>");
     }
 
     auto abbreviations = QStringLiteral("&nbsp;");
-    foreach (const auto &transition,
-             mTimezone.transitions(QDateTime::currentDateTime(),
-                                   QDateTime::currentDateTime().addYears(1))) {
+    foreach (const auto &transition, mTimezone.transitions(now, now.addYears(1))) {
         abbreviations += transition.abbreviation;
         abbreviations += QLatin1String(",&nbsp;");
     }
     abbreviations.chop(7);
     if (!abbreviations.isEmpty()) {
-        toolTip += i18n("<i>Abbreviations:</i>");
+        toolTip += i18nc("heading for comma-separated list of timezone abbreviations",
+                         "<i>Abbreviations:</i>");
         toolTip += abbreviations;
         toolTip += QLatin1String("<br/>");
     }
     const QString timeZoneComment(mTimezone.comment());
     if (!timeZoneComment.isEmpty()) {
-        toolTip += i18n("<i>Comment:</i> %1", timeZoneComment);
+        toolTip += i18nc("heading for the timezone comment",
+                         "<i>Comment:</i> %1", timeZoneComment);
     }
     toolTip += QLatin1String("</qt>");
 
     return toolTip;
 }
+
+bool TimeLabels::event(QEvent *event)
+{
+    if (event->type() == QEvent::ToolTip) {
+        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        const int cell = yposToCell(helpEvent->pos().y());
+
+        QString toolTip;
+        toolTip += QLatin1String("<qt>");
+        toolTip += i18nc("[hour of the day][am/pm/00] [timezone id (timezone-offset)]",
+                         "%1%2<br/>%3 (%4)",
+                         cellToHour(cell),  cellToSuffix(cell),
+                         i18n(mTimezone.id().constData()),
+                         KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
+        toolTip += QLatin1String("</qt>");
+
+        QToolTip::showText(helpEvent->globalPos(), toolTip, this);
+
+        return true;
+    }
+    return QWidget::event(event);
+}
