@@ -28,9 +28,7 @@
 
 #include <QFrame>
 
-namespace EventViews
-{
-
+namespace EventViews {
 class Agenda;
 class TimeLabelsZone;
 
@@ -43,7 +41,8 @@ class TimeLabels : public QFrame
 public:
     typedef QList<TimeLabels *> List;
 
-    TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr, Qt::WindowFlags f = nullptr);
+    TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr,
+               Qt::WindowFlags f = nullptr);
 
     /** updates widget's internal state */
     void updateConfig();
@@ -74,7 +73,14 @@ public:
 
     QSize minimumSizeHint() const override;
 
+    /** */
+    bool event(QEvent *event) override;
+
 private:
+    int yposToCell(const int ypos) const;
+    int cellToHour(const int cell) const;
+    QString cellToSuffix(const int cell) const;
+
     /** update the position of the marker showing the mouse position */
     void mousePosChanged(const QPoint &pos);
 
@@ -92,7 +98,6 @@ private:
 
     QFrame *mMousePos = nullptr;  // shows a marker for the current mouse position in y direction
 };
-
 }
 
 #endif
